BitWriteStream

Struct BitWriteStream 

pub struct BitWriteStream<'a, E>
where E: Endianness,
{ /* private fields */ }
Stream that provides an a way to write non bit aligned adata

Examples

use bitbuffer::{BitWriteStream, LittleEndian};

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);

stream.write_bool(false)?;
stream.write_int(123u16, 15)?;

Implementations

Source

impl<'a, E> BitWriteStream<'a, E>
where E: Endianness,

pub fn new(data: &'a mut Vec<u8>, endianness: E) -> Self

Create a new write stream

Examples
use bitbuffer::{BitWriteStream, LittleEndian};

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
pub fn from_slice(data: &'a mut [u8], endianness: E) -> Self

Create a new write stream

Note that the resulting stream will panic when trying to write more data then fits in the provided slice.

Source

impl<E> BitWriteStream<'_, E>
where E: Endianness,

pub fn bit_len(&self) -> usize

The number of written bits in the buffer

pub fn byte_len(&self) -> usize

The number of written bytes in the buffer

pub fn align(&mut self) -> usize

Align the stream on the next byte by writing zero bits and returns the amount of bits written

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_bool(true)?;
stream.align();
assert_eq!(stream.bit_len(), 8);
assert_eq!(data, [0b0000_0001]);
pub fn write_bool(&mut self, value: bool) -> Result<()>

Write a boolean into the buffer

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_bool(true)?;
pub fn write_int<T>(&mut self, value: T, count: usize) -> Result<()>

Write an integer into the buffer

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_int(123u16, 15)?;
pub fn write_float<T>(&mut self, value: T) -> Result<()>

Write a float into the buffer

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_float(123.15f32)?;
pub fn write_bytes(&mut self, bytes: &[u8]) -> Result<()>

Write a number of bytes into the buffer

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_bytes(&[0, 1, 2 ,3])?;
pub fn write_bits(&mut self, bits: &BitReadStream<'_, E>) -> Result<()>

Write bits from a read stream into the buffer

pub fn write_string( &mut self, string: &str, length: Option<usize>, ) -> Result<()>

Write a string into the buffer

Examples

let mut data = Vec::new();
let mut stream = BitWriteStream::new(&mut data, LittleEndian);
stream.write_string("zero terminated string", None)?;
stream.write_string("fixed size string, zero padded", Some(64))?;
pub fn write<T: BitWrite<E>>(&mut self, value: &T) -> Result<()>

Write the type to stream

pub fn write_sized<T: BitWriteSized<E>>( &mut self, value: &T, length: usize, ) -> Result<()>

Write the type to stream

pub fn reserve_length<Err: From<BitError>, F: Fn(&mut BitWriteStream<'_, E>) -> Result<(), Err>>( &mut self, length_bit_size: usize, body_fn: F, ) -> Result<(), Err>

Write the length of a section before the section

pub fn reserve_byte_length<Err: From<BitError>, F: Fn(&mut BitWriteStream<'_, E>) -> Result<(), Err>>( &mut self, length_bit_size: usize, body_fn: F, ) -> Result<(), Err>

Write the length in bytes of a section before the section, the section will be 0 padded to an even byte length

pub fn reserve_int<Err: From<BitError>, F: Fn(&mut BitWriteStream<'_, E>) -> Result<u64, Err>>( &mut self, count: usize, body_fn: F, ) -> Result<(), Err>

Reserve the length to write an integer